PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/ViaPainter.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
ViaPainter.hpp
1
2#ifndef GYM_PCB_UI_VIAPAINTER_H
3#define GYM_PCB_UI_VIAPAINTER_H
4
5#include "GLContext.hpp"
6
7class PCBoard;
8class Track;
9class Via;
10class Camera;
11
12 class ViaPainter
13{
14public:
15 ViaPainter();
16 ~ViaPainter();
17 void update(const PCBoard&);
18 void update(const Track&);
19 void update(const std::vector<const Via *>&);
20 void draw(const Camera&);
21private:
22 uint mNumVertices{0};
23
24 GLuint mVBO{0};
25 GLuint mVAO{0};
26
27 static GLuint sVP, sFP, sPP;
28
29 void createVAO();
30 static void createShaders();
31};
32
33#endif // GYM_PCB_UI_VIAPAINTER_H
Camera
Definition Camera.hpp:15
PCBoard
Definition PCBoard.hpp:36
Track
Definition Track.hpp:21
Via
Definition Via.hpp:10